@@ -8,10 +8,12 @@ int main(int argc, char *argv[])
 {
   MCAgency_t agency;
   MCAgencyOptions_t options;
+  int port = 5050;
+  int remote_port = 5051;
 
   MC_InitializeAgencyOptions(&options);
-  MC_SetThreadOff(&options, MC_THREAD_CP);
-  agency = MC_Initialize(5050, &options);
+  MC_SetThreadOff(&options, MC_THREAD_CP); /* Turn command prompt off.*/
+  agency = MC_Initialize(port , &options);
 
   printf("MobileC Started\n");
   printf("Sending agent1...\n");
@@ -21,7 +23,7 @@ int main(int argc, char *argv[])
       agency,
       "agent1.xml",
       "localhost",
-      5051);
+      remote_port);
   printf("Sleeping for %d seconds.\n", WAIT_TIME);
 #ifndef _WIN32
   sleep(WAIT_TIME);
@@ -35,7 +37,7 @@ int main(int argc, char *argv[])
       agency,
       "agent2.xml",
       "localhost",
-      5051);
+      remote_port);
 #ifndef _WIN32
   sleep(WAIT_TIME);
 #else
@@ -48,7 +50,7 @@ int main(int argc, char *argv[])
       agency,
       "agent3.xml",
       "localhost",
-      5051);
+      remote_port);
 
   printf("Terminating...\n");
   MC_End(agency);
