@@ -4,7 +4,8 @@
 int main(int argc, char *argv[]) 
 {
     MCAgency_t agency;
-    agency = MC_Initialize(5051, NULL);
+    int port=5051;
+    agency = MC_Initialize(port, NULL);
 
     printf("MobileC Started\n");
     MC_MainLoop(agency);
