@@ -3,6 +3,7 @@ using System.Collections.Generic;
 using System.Text;
 using LibMC;
 using System.Threading;
+using System.Runtime.InteropServices;
 
 /** \file /LibMCConsole/Program.cs
  * Program for starting a Mobile-C agency from a console. Also
@@ -18,12 +19,26 @@ using System.Threading;
  */
 namespace LibMCConsole
 {
+    /**
+     * \brief     Class for the main program.
+     * 
+     * Contains the Main function and variables, structs, etc. used
+     * by the program.
+     */
     class Program
     {
         public static MCAgency Agency = new MCAgency();
         public static int localport = 5050;
         public static int remoteport = 5051;
 
+        /**
+         * \brief     Main program for a general console program.
+         * 
+         * Creates an agency and hosts agents. It also looks for an agent
+         * named "mobagent1" and displays information about the agent. 
+         * Demonstrates terminating an agent, waiting on agency signals, 
+         * and basic agency operations.
+         */
         static void Main(string[] args)
         {
             int temp;
@@ -39,14 +54,13 @@ namespace LibMCConsole
 
             while (true)
             {
-                Thread.Sleep(5000);
+                Agency.WaitSignal((int)MCAgency.MC_Signal_e.MC_EXEC_AGENT);
+                Agency.ResetSignal();
                 try
                 {
-                    agent = Agency.FindAgentByName("persistent1");
+                    agent = Agency.FindAgentByName("mobagent1");
                     Console.WriteLine("Found agent\n" + agent.ToString() + ".");
-                    temp = agent.CallAgentFunc("func", IntPtr.Zero, IntPtr.Zero);
-                    Console.WriteLine("CallAgentFunc() returned " + 
-                        temp.ToString() + ".");
+
                     temp = agent.TerminateAgent();
                     Console.WriteLine("TerminateAgent() returned " + 
                         temp.ToString() + ".");
