@@ -6,17 +6,23 @@
 #ifdef _CH_
 #pragma package <cs2ch>
 #endif
+
 #include "cs2ch.h"
 
+/* Load code from file cs2chfunc.c for Ch */
+#ifdef _CH_
+//#pragma importf "cs2chfunc.c"
+#endif
+
 /* A message to show the difference between C/C# and Ch. */
 char* msg = 
 #ifdef _CH_ 
     "Hello in Ch!";
 #else
     "Hello from C!";
-#endif    
+#endif
 
-int STDCALL callback(char* s)
+int CALLBACK callback(char* s)
 {
     if (s != NULL)
     {
