@@ -21,10 +21,8 @@
 
 /* Calling convention definition for different platforms */
 #ifdef _CH_
-#define STDCALL
+#define CALLBACK
 #define EXPORTCH
-#else
-#define STDCALL __stdcall
 #endif
 
 /* Typedef for structs */
@@ -48,22 +46,22 @@ typedef struct struct2_s
 } struct2_t;
 
 /* Typedef for callbacks */
-typedef int (STDCALL *Fx)(char*);
+typedef int    (CALLBACK *Fx)(char*);
 
 /* Exported functions */
 EXPORTCH int add(int a, int b);
 EXPORTCH int func1(struct1_t s1, struct2_t s2);
 EXPORTCH double func2(struct1_t *s1, struct2_t *s2);
+EXPORTCH struct2_t* func3(struct1_t* s1);
 EXPORTCH struct1_t* new_struct1(void);
 EXPORTCH void free_struct1(struct1_t* s);
 EXPORTCH void free_struct2(struct2_t* s);
 EXPORTCH int setCallback(Fx f);
 EXPORTCH int callFptr(char* s);
 EXPORTCH int get_inc_int(void);
-
-/* Load code from file cs2chfunc.c for Ch */
-#ifdef _CH_
-#pragma importf "cs2chfunc.c"
-#endif
+EXPORTCH int get_int(void);
+EXPORTCH double doublesum(double a, double b);
+EXPORTCH int dll_init(void);
+EXPORTCH int dll_exit(void);
 
 #endif /* CS2CH_H */
