@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 182 $ : Last Committed Revision
- * $Date: 2008-07-01 15:38:28 -0700 (Tue, 01 Jul 2008) $ : Last Committed Date */
+ * $Revision: 207 $ : Last Committed Revision
+ * $Date: 2008-07-11 17:55:19 -0700 (Fri, 11 Jul 2008) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -36,7 +36,8 @@
 #define _FIPA_ACL_MESSAGE_H_
 #include "dynstring.h"
 
-
+#ifndef _FIPA_PERFORMATIVE_E_
+#define _FIPA_PERFORMATIVE_E_
 enum fipa_performative_e
 {
   FIPA_ERROR=-1,
@@ -64,6 +65,7 @@ enum fipa_performative_e
   FIPA_REQUEST_WHENEVER,
   FIPA_SUBSCRIBE
 };
+#endif
 
 int fipa_performative_Compose(dynstring_t* msg, enum fipa_performative_e performative);
 
