@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 182 $ : Last Committed Revision
- * $Date: 2008-07-01 15:38:28 -0700 (Tue, 01 Jul 2008) $ : Last Committed Date */
+ * $Revision: 207 $ : Last Committed Revision
+ * $Date: 2008-07-11 17:55:19 -0700 (Fri, 11 Jul 2008) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -205,8 +205,8 @@ enum MC_Signal_e{
     MC_RECV_MESSAGE   =0x02, /*!< A Message has been received from a connection */
     MC_RECV_AGENT     =0x04, /*!< An normal agent has been parsed from a message */
     MC_RECV_RETURN    =0x08, /*!< A return agent has been parsed from a message */
-    MC_EXEC_AGENT     =0x0F, /*!< A normal agent has been executed. */
-    MC_ALL_SIGNALS    =0x10  /*!< Catch any of the above signals */
+    MC_EXEC_AGENT     =0x10, /*!< A normal agent has been executed. */
+    MC_ALL_SIGNALS    =0x20  /*!< Catch any of the above signals */
 };
 
 /**
@@ -264,7 +264,38 @@ enum MC_AgentStatus_e{
     MC_WAIT_FINISHED   /*!< Finished, waiting to be flushed */
 };
 
+/** FIPA ACL **/
 struct fipa_acl_message_s;
+#ifndef _FIPA_PERFORMATIVE_E_
+#define _FIPA_PERFORMATIVE_E_
+enum fipa_performative_e
+{
+  FIPA_ERROR=-1,
+  FIPA_ZERO,
+  FIPA_ACCEPT_PROPOSAL,
+  FIPA_AGREE,
+  FIPA_CANCEL,
+  FIPA_CALL_FOR_PROPOSAL,
+  FIPA_CONFIRM,
+  FIPA_DISCONFIRM,
+  FIPA_FAILURE,
+  FIPA_INFORM,
+  FIPA_INFORM_IF,
+  FIPA_INFORM_REF,
+  FIPA_NOT_UNDERSTOOD,
+  FIPA_PROPOGATE,
+  FIPA_PROPOSE,
+  FIPA_PROXY,
+  FIPA_QUERY_IF,
+  FIPA_QUERY_REF,
+  FIPA_REFUSE,
+  FIPA_REJECT_PROPOSAL,
+  FIPA_REQUEST,
+  FIPA_REQUEST_WHEN,
+  FIPA_REQUEST_WHENEVER,
+  FIPA_SUBSCRIBE
+};
+#endif
 
 /**
  * \brief         Destroy a FIPA ACL message
