@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 182 $ : Last Committed Revision
- * $Date: 2008-07-01 15:38:28 -0700 (Tue, 01 Jul 2008) $ : Last Committed Date */
+ * $Revision: 207 $ : Last Committed Revision
+ * $Date: 2008-07-11 17:55:19 -0700 (Fri, 11 Jul 2008) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -138,6 +138,9 @@ typedef struct mtp_http_s
   int message_parts;
   char* boundary;
   struct mtp_http_content_s* content;
+
+  /* The following is not a part of the HTTP standard, but is useful. */
+  int header_length;
 } mtp_http_t;
 typedef mtp_http_t* mtp_http_p;
 
@@ -173,7 +176,7 @@ int http_ParseExpression(
     char** value
     );
 
-const char* http_ParseHeader(
+const char* http_ParseRequest(
     mtp_http_p http,
     const char* string
     );
@@ -192,6 +195,9 @@ mtp_http_p
 mtp_http_New(void);
 
 struct connection;
+const char* 
+mtp_http_ParseHeader(struct mtp_http_s* http, const char* string);
+
 int 
 mtp_http_Parse(struct mtp_http_s* http, const char* string);
 
