@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 182 $ : Last Committed Revision
- * $Date: 2008-07-01 15:38:28 -0700 (Tue, 01 Jul 2008) $ : Last Committed Date */
+ * $Revision: 207 $ : Last Committed Revision
+ * $Date: 2008-07-11 17:55:19 -0700 (Fri, 11 Jul 2008) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -667,7 +667,6 @@ MC_End(MCAgency_t agency) /*{{{*/
   MUTEX_LOCK(agency->mc_platform->quit_lock);
   agency->mc_platform->quit = 1;
   MUTEX_UNLOCK(agency->mc_platform->quit_lock);
-  COND_SIGNAL(agency->mc_platform->df->request_list->cond);
 
   /* Stop the command prompt */
   if( GET_THREAD_MODE( agency->threads, MC_THREAD_CP)) {
@@ -686,6 +685,7 @@ MC_End(MCAgency_t agency) /*{{{*/
   }
 
   /* Stop the message queue */
+  COND_SIGNAL(agency->mc_platform->message_queue->cond);
   if( GET_THREAD_MODE( agency->threads, MC_THREAD_ACC)) {
     THREAD_JOIN(agency->mc_platform->acc->message_handler_thread);
   }
@@ -696,7 +696,8 @@ MC_End(MCAgency_t agency) /*{{{*/
     THREAD_JOIN(agency->mc_platform->ams->thread);
   }
 
-
+  /* Stop the DF */
+  COND_SIGNAL(agency->mc_platform->df->request_list->cond);
   if( GET_THREAD_MODE( agency->threads, MC_THREAD_DF)) {
     THREAD_JOIN(agency->mc_platform->df->thread);
   }
