@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 182 $ : Last Committed Revision
- * $Date: 2008-07-01 15:38:28 -0700 (Tue, 01 Jul 2008) $ : Last Committed Date */
+ * $Revision: 207 $ : Last Committed Revision
+ * $Date: 2008-07-11 17:55:19 -0700 (Fri, 11 Jul 2008) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -100,16 +100,17 @@ mtp_http_InitializeFromConnection
  )
 {
   int i=1;
-  int n;
-  char *message_string;
+  int n = 0;
+  dynstring_t* message_string;
   char *buffer;
   int message_size = 0;
+  int received_len = 0;
+
+  mtp_http_t* http_header;
 
   buffer = (char*) malloc(sizeof(char) * (SOCKET_INPUT_SIZE + 1));
   CHECK_NULL(buffer, exit(0););
-  message_string = (char*) malloc(sizeof(char) * (SOCKET_INPUT_SIZE + 1));
-  CHECK_NULL(message_string, exit(0););
-  message_string[0] = '\0';
+  message_string = dynstring_New();
   buffer[0] = '\0';
 
   while(1){
@@ -128,6 +129,7 @@ mtp_http_InitializeFromConnection
         (struct sockaddr *) 0,
         0);
 #endif
+    received_len += n;
     if (n < 0) {
       free(buffer);
       return MC_ERR_CONNECT;
@@ -135,10 +137,27 @@ mtp_http_InitializeFromConnection
     else if (n == 0 || n < SOCKET_INPUT_SIZE) {
       if (n != 0) {
         buffer[n] = '\0';
-        strcat(message_string, buffer);
+        dynstring_Append(message_string, buffer);
       }
+      /* Here, we must check the http header to make sure that we have received the
+       * entire message. If not, continue the loop. */
+      http_header = mtp_http_New();
+      if(mtp_http_ParseHeader(http_header, message_string->message) == NULL) {
+        fprintf(stderr, "Error parsing HTTP Header. %s:%d\n",
+            __FILE__, __LINE__);
+        dynstring_Destroy(message_string);
+        mtp_http_Destroy(http_header);
+        free(buffer);
+        return 2;
+      }
+      if ( received_len < (atoi(http_header->content_length) + http_header->header_length) ) {
+        mtp_http_Destroy(http_header);
+        continue;
+      }
+      mtp_http_Destroy(http_header);
+
       free(buffer);
-      if(mtp_http_Parse(http, message_string)) {
+      if(mtp_http_Parse(http, message_string->message)) {
         /* Reply with an HTTP error code */
         buffer = malloc
           (
@@ -162,11 +181,11 @@ mtp_http_InitializeFromConnection
            sizeof(char)*(strlen(buffer)),
            0
           );
-        free(message_string);
+        dynstring_Destroy(message_string);
         free(buffer);
         return ERR;
       } else {
-        free(message_string);
+        dynstring_Destroy(message_string);
       }
 
       if (n < SOCKET_INPUT_SIZE) {
@@ -188,17 +207,11 @@ mtp_http_InitializeFromConnection
       message_size += n;
       buffer[n] = '\0';
       i++;
-      strcat(message_string, buffer);
-      message_string = realloc
-        (
-         message_string, 
-         sizeof(char) * (SOCKET_INPUT_SIZE+1) * i
-        );
-      CHECK_NULL(message_string, exit(0););
+      dynstring_Append(message_string, buffer);
       buffer[0] = '\0';
       if (!strcmp
           (
-           message_string + message_size - 4,
+           message_string->message + message_size - 4,
            "\r\n\r\n"
           )
          )
@@ -326,21 +339,17 @@ int http_ParseExpression(
   return MC_SUCCESS;
 }
 
-int
-mtp_http_Parse(struct mtp_http_s* http, const char* string)
+const char* mtp_http_ParseHeader(struct mtp_http_s* http, const char* string)
 {
   const char* line = NULL;
   char* expr = NULL;
   char* name = NULL;
   char* value = NULL;
-  char* tmp;
-  char* tmp2;
-  int i;
 
   int err_code = 0;
 
   line = string;
-  line = http_ParseHeader
+  line = http_ParseRequest
     (
      http,
      line
@@ -407,6 +416,25 @@ mtp_http_Parse(struct mtp_http_s* http, const char* string)
 #undef SAFE_FREE
      
   } while(line != NULL && err_code == MC_SUCCESS);
+
+  http->header_length = line - string - 1;
+  return line;
+}
+
+int
+mtp_http_Parse(struct mtp_http_s* http, const char* string)
+{
+  const char* line;
+  char* expr = NULL;
+  char* name = NULL;
+  char* value = NULL;
+  char* tmp;
+  char* tmp2;
+  int i;
+
+  int err_code = 0;
+
+  line = mtp_http_ParseHeader(http, string);
   /* If the content type is multipart/mixed, then we need to
    * figure out how many parts there are. */
   if( 
@@ -542,7 +570,7 @@ mtp_http_Parse(struct mtp_http_s* http, const char* string)
     return 1;
 }
 
-const char* http_ParseHeader(
+const char* http_ParseRequest(
     mtp_http_p http,
     const char* string )
 {
