@@ -293,6 +293,18 @@ using System.Runtime.InteropServices;
  * Demonstrates miscellaneous Mobile-C functions.
  */
 
+/** 
+ * \example LibMCInterop/Program.cs
+ * Demonstrates interfacing with a .dl file and calling
+ * agent functions.
+ */
+
+/** 
+ * \example cs2ch/cs2chfunc.c
+ * C library example that allows agents to call CLI
+ * functions.
+ */
+
 /** 
  * \example LibMCCppEx/LibMCCppEx.cpp
  * \dontinclude LibMCCppEx/Form1.h
@@ -378,16 +390,18 @@ namespace LibMC
             get
             {
                 if (agency_p == IntPtr.Zero)
-                    throw new SystemException("Private agency pointer is zero!");
+                    throw new InvalidAgentException();
                 else
                     return agency_p;
             }
             set
             {
-                if (agency_p == IntPtr.Zero)
+                if (value == IntPtr.Zero)
+                    throw new InvalidAgentException("Attempting to assign null pointer to agency internal pointer!");
+                else if (agency_p == IntPtr.Zero)
                     agency_p = value;
                 else
-                    throw new SystemException("Attempting to assign new agency to non-zero agency pointer!");
+                    throw new InvalidAgentException("Attempting to assign new agency to non-zero agency pointer!");
             }
         }
 
@@ -1049,4 +1063,39 @@ namespace LibMC
             return _MC_MainLoop(Agency);
         }
     }
+
+    /**
+     * \brief   Exception class for use with null agency pointers
+     * 
+     * This class provides a way to inform the program that an
+     * agency was created or accessed that had an invalid
+     * internal pointer.
+     */
+    public class InvalidAgencyException : SystemException
+    {
+        private const String msg = "Private agency pointer not valid.";
+
+        /**
+         * \brief   Null agency pointer exception constructor.
+         * 
+         * Constructor for the exception class. This exception
+         * simply defines a recognizable exception class and sets
+         * the exception message appropriately.
+         */
+        public InvalidAgencyException()
+            : base(msg)
+        {
+        }
+
+        /**
+         * \brief   Null agency pointer exception constructor.
+         * 
+         * Constructor for the exception class. Allows the use
+         * of a custom error message.
+         */
+        public InvalidAgencyException(String exc)
+            : base(exc)
+        {
+        }
+    }
 }
