@@ -108,14 +108,14 @@ namespace LibMC
          *
          * \sa        MC_WaitSignal(), MC_ResetSignal()
          */
-        enum MC_Signal_e{
+        public enum MC_Signal_e{
             MC_NO_SIGNAL       = 0x00,
             MC_RECV_CONNECTION = 0x01,
             MC_RECV_MESSAGE    = 0x02,
             MC_RECV_AGENT      = 0x04,
             MC_RECV_RETURN     = 0x08,
-            MC_EXEC_AGENT      = 0x0F,
-            MC_ALL_SIGNALS     = 0x10
+            MC_EXEC_AGENT      = 0x10,
+            MC_ALL_SIGNALS     = 0x20
         };
 
         /*
